==> express-sitemap-1.6.2.tgz: package/History.md <==
v1.6.2 / 2015-11-28
==================

  * Test `node`@5
  * Update `setheaders`@0.1.5
  * Update `tickle`@1.2.3

v1.6.1 / 2015-10-01
==================

  * Test `node`@4
  * Update `setheaders`@0.1.4
  * Update `tickle`@1.2.2

v1.6.0 / 2015-08-21
==================

  * SPDX license
  * Add `setheaders`@0.1.3
  * Update `tickle`@1.2.1

v1.5.6 / 2015-05-09
==================

  * Add `sitemapSubmission` (options)

v1.5.5 / 2015-04-24
==================

  * Update `tickle`@1.2.0

v1.5.4 / 2015-03-28
==================

  * Add functionality to indicate alternate language pages in sitemap (@Twissi)

v1.5.3 / 2015-02-25
==================

  * Fix nested Router when path is "/"
  * Add `setheaders`@0.1.1
  * Update `tickle`@1.1.9
  * `coveralls` test

v1.5.2 / 2015-02-21
==================

  * Support for express nested Router

v1.5.1 / 2015-02-19
==================

  * Fix for express4.Router()

v1.5.0 / 2015-02-16
==================

  * Add `cache` (options)
  * `windows` test
  * `iojs` test

v1.4.0 / 2015-01-16
==================

  * Update coverage for express3.x

v1.3.8 / 2014-11-19
==================

  * Strict check
  * Update `tickle`@1.1.8

v1.3.7 / 2014-10-26
==================

  * `jshint`

v1.3.6 / 2014-10-04
==================

  * Remove jsdoc
  * `package.json` min

v1.3.4 / 2014-08-23
==================

  * Performance tips

v1.3.3 / 2014-08-14
==================

  * Update `tickle`@1.1.3

v1.3.2 / 2014-08-11
==================

  * Update README.md

v1.3.1 / 2014-08-04
==================

  * Resolve path for "robots" and "sitemap"

v1.3.0 / 2014-07-27
==================

  * Test "node": ">=0.10.0" only
  * Using task runner `grunt`
  * Using test framework `mocha`
  * Testing script will be put inside "test/"
  * ".npmignore" more aggressive
  * `uglify` compiles
  * `jsdoc` documentation

v1.2.3 / 2014-07-25
==================

  * Update `tickle`@1.0.4

v1.2.2 / 2014-06-29
==================

  * Remove anonymous function

v1.2.1 / 2014-06-22
==================

  * Doc update
  * `toWeb()` fix
  * Add `hide` var to `route` option

v1.2.0 / 2014-06-21
==================

  * Rename `sitemap` option to `map`
  * Rename `file` option to `sitemap`
  * Change type of `robots` option. Now accept String
  * Sitemap generate url for GET request only
  * Fix `toFile()` function

v1.1.0 / 2014-06-21
==================

  * Resolve middleware or dynamic building
  * robots.txt builder
  * Add `robots` option
  * Change name of methods

v1.0.1 / 2014-06-20
==================

  * Web output
  * Add `generate` option

v1.0.0 / 2014-06-20
==================

  * First operative release

v0.0.2 / 2014-06-19
==================

  * Documentation

v0.0.1 / 2014-06-19
==================

  * Project start

==> express-sitemap-1.6.3.tgz: package/History.md <==
v1.6.3 / 2015-01-30
==================

  * Tested against `node`@5.3
  * Support for callback in *ToFile functions

v1.6.2 / 2015-11-28
==================

  * Tested against `node`@5
  * Update `setheaders`@0.1.5
  * Update `tickle`@1.2.3

v1.6.1 / 2015-10-01
==================

  * Tested against `node`@4
  * Update `setheaders`@0.1.4
  * Update `tickle`@1.2.2

v1.6.0 / 2015-08-21
==================

  * SPDX license
  * Add `setheaders`@0.1.3
  * Update `tickle`@1.2.1

v1.5.6 / 2015-05-09
==================

  * Add `sitemapSubmission` (options)

v1.5.5 / 2015-04-24
==================

  * Update `tickle`@1.2.0

v1.5.4 / 2015-03-28
==================

  * Add functionality to indicate alternate language pages in sitemap (@Twissi)

v1.5.3 / 2015-02-25
==================

  * Fix nested Router when path is "/"
  * Add `setheaders`@0.1.1
  * Update `tickle`@1.1.9
  * `coveralls` test

v1.5.2 / 2015-02-21
==================

  * Support for express nested Router

v1.5.1 / 2015-02-19
==================

  * Fix for express4.Router()

v1.5.0 / 2015-02-16
==================

  * Add `cache` (options)
  * `windows` test
  * `iojs` test

v1.4.0 / 2015-01-16
==================

  * Update coverage for express3.x

v1.3.8 / 2014-11-19
==================

  * Strict check
  * Update `tickle`@1.1.8

v1.3.7 / 2014-10-26
==================

  * `jshint`

v1.3.6 / 2014-10-04
==================

  * Remove jsdoc
  * `package.json` min

v1.3.4 / 2014-08-23
==================

  * Performance tips

v1.3.3 / 2014-08-14
==================

  * Update `tickle`@1.1.3

v1.3.2 / 2014-08-11
==================

  * Update README.md

v1.3.1 / 2014-08-04
==================

  * Resolve path for "robots" and "sitemap"

v1.3.0 / 2014-07-27
==================

  * Tested against "node": ">=0.10.0" only
  * Using task runner `grunt`
  * Using test framework `mocha`
  * Testing script will be put inside "test/"
  * ".npmignore" more aggressive
  * `uglify` compiles
  * `jsdoc` documentation

v1.2.3 / 2014-07-25
==================

  * Update `tickle`@1.0.4

v1.2.2 / 2014-06-29
==================

  * Remove anonymous function

v1.2.1 / 2014-06-22
==================

  * Doc update
  * `toWeb()` fix
  * Add `hide` var to `route` option

v1.2.0 / 2014-06-21
==================

  * Rename `sitemap` option to `map`
  * Rename `file` option to `sitemap`
  * Change type of `robots` option. Now accept String
  * Sitemap generate url for GET request only
  * Fix `toFile()` function

v1.1.0 / 2014-06-21
==================

  * Resolve middleware or dynamic building
  * robots.txt builder
  * Add `robots` option
  * Change name of methods

v1.0.1 / 2014-06-20
==================

  * Web output
  * Add `generate` option

v1.0.0 / 2014-06-20
==================

  * First operative release

v0.0.2 / 2014-06-19
==================

  * Documentation

v0.0.1 / 2014-06-19
==================

  * Project start
